pre { line-height: 125%; 
}

td.linenos .normal { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

td.linenos .special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos.special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}
.pygments-style-borland .hll { background-color: #ffc }

.pygments-style-borland { background: #fff; 
}

.pygments-style-borland .c { color: #080; 
font-style: italic } /* Comment */
.pygments-style-borland .err { color: #a61717; 
background-color: #e3d2d2 } /* Error */
.pygments-style-borland .k { color: #000080; 
font-weight: bold } /* Keyword */
.pygments-style-borland .ch { color: #080; 
font-style: italic } /* Comment.Hashbang */
.pygments-style-borland .cm { color: #080; 
font-style: italic } /* Comment.Multiline */
.pygments-style-borland .cp { color: #008080 } /* Comment.Preproc */
.pygments-style-borland .cpf { color: #080; 
font-style: italic } /* Comment.PreprocFile */
.pygments-style-borland .c1 { color: #080; 
font-style: italic } /* Comment.Single */
.pygments-style-borland .cs { color: #080; 
font-weight: bold } /* Comment.Special */
.pygments-style-borland .gd { color: #000; 
background-color: #fdd } /* Generic.Deleted */
.pygments-style-borland .ge { font-style: italic } /* Generic.Emph */
.pygments-style-borland .ges { font-weight: bold; 
font-style: italic } /* Generic.EmphStrong */
.pygments-style-borland .gr { color: #a00 } /* Generic.Error */
.pygments-style-borland .gh { color: #999 } /* Generic.Heading */
.pygments-style-borland .gi { color: #000; 
background-color: #dfd } /* Generic.Inserted */
.pygments-style-borland .go { color: #888 } /* Generic.Output */
.pygments-style-borland .gp { color: #555 } /* Generic.Prompt */
.pygments-style-borland .gs { font-weight: bold } /* Generic.Strong */
.pygments-style-borland .gu { color: #aaa } /* Generic.Subheading */
.pygments-style-borland .gt { color: #a00 } /* Generic.Traceback */
.pygments-style-borland .kc { color: #000080; 
font-weight: bold } /* Keyword.Constant */
.pygments-style-borland .kd { color: #000080; 
font-weight: bold } /* Keyword.Declaration */
.pygments-style-borland .kn { color: #000080; 
font-weight: bold } /* Keyword.Namespace */
.pygments-style-borland .kp { color: #000080; 
font-weight: bold } /* Keyword.Pseudo */
.pygments-style-borland .kr { color: #000080; 
font-weight: bold } /* Keyword.Reserved */
.pygments-style-borland .kt { color: #000080; 
font-weight: bold } /* Keyword.Type */
.pygments-style-borland .m { color: #00F } /* Literal.Number */
.pygments-style-borland .s { color: #00F } /* Literal.String */
.pygments-style-borland .na { color: #F00 } /* Name.Attribute */
.pygments-style-borland .nt { color: #000080; 
font-weight: bold } /* Name.Tag */
.pygments-style-borland .ow { font-weight: bold } /* Operator.Word */
.pygments-style-borland .w { color: #bbb } /* Text.Whitespace */
.pygments-style-borland .mb { color: #00F } /* Literal.Number.Bin */
.pygments-style-borland .mf { color: #00F } /* Literal.Number.Float */
.pygments-style-borland .mh { color: #00F } /* Literal.Number.Hex */
.pygments-style-borland .mi { color: #00F } /* Literal.Number.Integer */
.pygments-style-borland .mo { color: #00F } /* Literal.Number.Oct */
.pygments-style-borland .sa { color: #00F } /* Literal.String.Affix */
.pygments-style-borland .sb { color: #00F } /* Literal.String.Backtick */
.pygments-style-borland .sc { color: #800080 } /* Literal.String.Char */
.pygments-style-borland .dl { color: #00F } /* Literal.String.Delimiter */
.pygments-style-borland .sd { color: #00F } /* Literal.String.Doc */
.pygments-style-borland .s2 { color: #00F } /* Literal.String.Double */
.pygments-style-borland .se { color: #00F } /* Literal.String.Escape */
.pygments-style-borland .sh { color: #00F } /* Literal.String.Heredoc */
.pygments-style-borland .si { color: #00F } /* Literal.String.Interpol */
.pygments-style-borland .sx { color: #00F } /* Literal.String.Other */
.pygments-style-borland .sr { color: #00F } /* Literal.String.Regex */
.pygments-style-borland .s1 { color: #00F } /* Literal.String.Single */
.pygments-style-borland .ss { color: #00F } /* Literal.String.Symbol */
.pygments-style-borland .il { color: #00F } /* Literal.Number.Integer.Long */
