pre { line-height: 125%; 
}

td.linenos .normal { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

td.linenos .special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos.special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}
.pygments-style-pastie .hll { background-color: #ffc }

.pygments-style-pastie { background: #fff; 
}
.pygments-style-pastie .c { color: #888 } /* Comment */
.pygments-style-pastie .err { color: #a61717; 
background-color: #e3d2d2 } /* Error */
.pygments-style-pastie .k { color: #080; 
font-weight: bold } /* Keyword */
.pygments-style-pastie .ch { color: #888 } /* Comment.Hashbang */
.pygments-style-pastie .cm { color: #888 } /* Comment.Multiline */
.pygments-style-pastie .cp { color: #c00; 
font-weight: bold } /* Comment.Preproc */
.pygments-style-pastie .cpf { color: #888 } /* Comment.PreprocFile */
.pygments-style-pastie .c1 { color: #888 } /* Comment.Single */
.pygments-style-pastie .cs { color: #c00; 
font-weight: bold; 
background-color: #fff0f0 } /* Comment.Special */
.pygments-style-pastie .gd { color: #000; 
background-color: #fdd } /* Generic.Deleted */
.pygments-style-pastie .ge { font-style: italic } /* Generic.Emph */
.pygments-style-pastie .ges { font-weight: bold; 
font-style: italic } /* Generic.EmphStrong */
.pygments-style-pastie .gr { color: #a00 } /* Generic.Error */
.pygments-style-pastie .gh { color: #333 } /* Generic.Heading */
.pygments-style-pastie .gi { color: #000; 
background-color: #dfd } /* Generic.Inserted */
.pygments-style-pastie .go { color: #888 } /* Generic.Output */
.pygments-style-pastie .gp { color: #555 } /* Generic.Prompt */
.pygments-style-pastie .gs { font-weight: bold } /* Generic.Strong */
.pygments-style-pastie .gu { color: #666 } /* Generic.Subheading */
.pygments-style-pastie .gt { color: #a00 } /* Generic.Traceback */
.pygments-style-pastie .kc { color: #080; 
font-weight: bold } /* Keyword.Constant */
.pygments-style-pastie .kd { color: #080; 
font-weight: bold } /* Keyword.Declaration */
.pygments-style-pastie .kn { color: #080; 
font-weight: bold } /* Keyword.Namespace */
.pygments-style-pastie .kp { color: #080 } /* Keyword.Pseudo */
.pygments-style-pastie .kr { color: #080; 
font-weight: bold } /* Keyword.Reserved */
.pygments-style-pastie .kt { color: #888; 
font-weight: bold } /* Keyword.Type */
.pygments-style-pastie .m { color: #00D; 
font-weight: bold } /* Literal.Number */
.pygments-style-pastie .s { color: #d20; 
background-color: #fff0f0 } /* Literal.String */
.pygments-style-pastie .na { color: #369 } /* Name.Attribute */
.pygments-style-pastie .nb { color: #038 } /* Name.Builtin */
.pygments-style-pastie .nc { color: #b06; 
font-weight: bold } /* Name.Class */
.pygments-style-pastie .no { color: #036; 
font-weight: bold } /* Name.Constant */
.pygments-style-pastie .nd { color: #555 } /* Name.Decorator */
.pygments-style-pastie .ne { color: #b06; 
font-weight: bold } /* Name.Exception */
.pygments-style-pastie .nf { color: #06b; 
font-weight: bold } /* Name.Function */
.pygments-style-pastie .nl { color: #369; 
font-style: italic } /* Name.Label */
.pygments-style-pastie .nn { color: #b06; 
font-weight: bold } /* Name.Namespace */
.pygments-style-pastie .py { color: #369; 
font-weight: bold } /* Name.Property */
.pygments-style-pastie .nt { color: #b06; 
font-weight: bold } /* Name.Tag */
.pygments-style-pastie .nv { color: #369 } /* Name.Variable */
.pygments-style-pastie .ow { color: #080 } /* Operator.Word */
.pygments-style-pastie .w { color: #bbb } /* Text.Whitespace */
.pygments-style-pastie .mb { color: #00D; 
font-weight: bold } /* Literal.Number.Bin */
.pygments-style-pastie .mf { color: #00D; 
font-weight: bold } /* Literal.Number.Float */
.pygments-style-pastie .mh { color: #00D; 
font-weight: bold } /* Literal.Number.Hex */
.pygments-style-pastie .mi { color: #00D; 
font-weight: bold } /* Literal.Number.Integer */
.pygments-style-pastie .mo { color: #00D; 
font-weight: bold } /* Literal.Number.Oct */
.pygments-style-pastie .sa { color: #d20; 
background-color: #fff0f0 } /* Literal.String.Affix */
.pygments-style-pastie .sb { color: #d20; 
background-color: #fff0f0 } /* Literal.String.Backtick */
.pygments-style-pastie .sc { color: #d20; 
background-color: #fff0f0 } /* Literal.String.Char */
.pygments-style-pastie .dl { color: #d20; 
background-color: #fff0f0 } /* Literal.String.Delimiter */
.pygments-style-pastie .sd { color: #d20; 
background-color: #fff0f0 } /* Literal.String.Doc */
.pygments-style-pastie .s2 { color: #d20; 
background-color: #fff0f0 } /* Literal.String.Double */
.pygments-style-pastie .se { color: #04d; 
background-color: #fff0f0 } /* Literal.String.Escape */
.pygments-style-pastie .sh { color: #d20; 
background-color: #fff0f0 } /* Literal.String.Heredoc */
.pygments-style-pastie .si { color: #33b; 
background-color: #fff0f0 } /* Literal.String.Interpol */
.pygments-style-pastie .sx { color: #2b2; 
background-color: #f0fff0 } /* Literal.String.Other */
.pygments-style-pastie .sr { color: #080; 
background-color: #fff0ff } /* Literal.String.Regex */
.pygments-style-pastie .s1 { color: #d20; 
background-color: #fff0f0 } /* Literal.String.Single */
.pygments-style-pastie .ss { color: #a60; 
background-color: #fff0f0 } /* Literal.String.Symbol */
.pygments-style-pastie .bp { color: #038 } /* Name.Builtin.Pseudo */
.pygments-style-pastie .fm { color: #06b; 
font-weight: bold } /* Name.Function.Magic */
.pygments-style-pastie .vc { color: #369 } /* Name.Variable.Class */
.pygments-style-pastie .vg { color: #d70 } /* Name.Variable.Global */
.pygments-style-pastie .vi { color: #33b } /* Name.Variable.Instance */
.pygments-style-pastie .vm { color: #369 } /* Name.Variable.Magic */
.pygments-style-pastie .il { color: #00D; 
font-weight: bold } /* Literal.Number.Integer.Long */
