pre { line-height: 125%; 
}

td.linenos .normal { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

td.linenos .special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos.special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}
.pygments-style-algol .hll { background-color: #ffc }

.pygments-style-algol { background: #fff; 
}

.pygments-style-algol .c { color: #888; 
font-style: italic } /* Comment */
.pygments-style-algol .err { border: 1px solid #F00 } /* Error */
.pygments-style-algol .k { font-weight: bold; 
text-decoration: underline } /* Keyword */
.pygments-style-algol .ch { color: #888; 
font-style: italic } /* Comment.Hashbang */
.pygments-style-algol .cm { color: #888; 
font-style: italic } /* Comment.Multiline */
.pygments-style-algol .cp { color: #888; 
font-weight: bold } /* Comment.Preproc */
.pygments-style-algol .cpf { color: #888; 
font-style: italic } /* Comment.PreprocFile */
.pygments-style-algol .c1 { color: #888; 
font-style: italic } /* Comment.Single */
.pygments-style-algol .cs { color: #888; 
font-weight: bold } /* Comment.Special */
.pygments-style-algol .kc { font-weight: bold; 
text-decoration: underline } /* Keyword.Constant */
.pygments-style-algol .kd { font-weight: bold; 
font-style: italic; 
text-decoration: underline } /* Keyword.Declaration */
.pygments-style-algol .kn { font-weight: bold; 
text-decoration: underline } /* Keyword.Namespace */
.pygments-style-algol .kp { font-weight: bold; 
text-decoration: underline } /* Keyword.Pseudo */
.pygments-style-algol .kr { font-weight: bold; 
text-decoration: underline } /* Keyword.Reserved */
.pygments-style-algol .kt { font-weight: bold; 
text-decoration: underline } /* Keyword.Type */
.pygments-style-algol .s { color: #666; 
font-style: italic } /* Literal.String */
.pygments-style-algol .nb { font-weight: bold; 
font-style: italic } /* Name.Builtin */
.pygments-style-algol .nc { color: #666; 
font-weight: bold; 
font-style: italic } /* Name.Class */
.pygments-style-algol .no { color: #666; 
font-weight: bold; 
font-style: italic } /* Name.Constant */
.pygments-style-algol .nf { color: #666; 
font-weight: bold; 
font-style: italic } /* Name.Function */
.pygments-style-algol .nn { color: #666; 
font-weight: bold; 
font-style: italic } /* Name.Namespace */
.pygments-style-algol .nv { color: #666; 
font-weight: bold; 
font-style: italic } /* Name.Variable */
.pygments-style-algol .ow { font-weight: bold } /* Operator.Word */
.pygments-style-algol .sa { color: #666; 
font-style: italic } /* Literal.String.Affix */
.pygments-style-algol .sb { color: #666; 
font-style: italic } /* Literal.String.Backtick */
.pygments-style-algol .sc { color: #666; 
font-style: italic } /* Literal.String.Char */
.pygments-style-algol .dl { color: #666; 
font-style: italic } /* Literal.String.Delimiter */
.pygments-style-algol .sd { color: #666; 
font-style: italic } /* Literal.String.Doc */
.pygments-style-algol .s2 { color: #666; 
font-style: italic } /* Literal.String.Double */
.pygments-style-algol .se { color: #666; 
font-style: italic } /* Literal.String.Escape */
.pygments-style-algol .sh { color: #666; 
font-style: italic } /* Literal.String.Heredoc */
.pygments-style-algol .si { color: #666; 
font-style: italic } /* Literal.String.Interpol */
.pygments-style-algol .sx { color: #666; 
font-style: italic } /* Literal.String.Other */
.pygments-style-algol .sr { color: #666; 
font-style: italic } /* Literal.String.Regex */
.pygments-style-algol .s1 { color: #666; 
font-style: italic } /* Literal.String.Single */
.pygments-style-algol .ss { color: #666; 
font-style: italic } /* Literal.String.Symbol */
.pygments-style-algol .bp { font-weight: bold; 
font-style: italic } /* Name.Builtin.Pseudo */
.pygments-style-algol .fm { color: #666; 
font-weight: bold; 
font-style: italic } /* Name.Function.Magic */
.pygments-style-algol .vc { color: #666; 
font-weight: bold; 
font-style: italic } /* Name.Variable.Class */
.pygments-style-algol .vg { color: #666; 
font-weight: bold; 
font-style: italic } /* Name.Variable.Global */
.pygments-style-algol .vi { color: #666; 
font-weight: bold; 
font-style: italic } /* Name.Variable.Instance */
.pygments-style-algol .vm { color: #666; 
font-weight: bold; 
font-style: italic } /* Name.Variable.Magic */
