pre { line-height: 125%; 
}

td.linenos .normal { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

td.linenos .special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos.special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}
.pygments-style-bw .hll { background-color: #ffc }

.pygments-style-bw { background: #fff; 
}
.pygments-style-bw .c { font-style: italic } /* Comment */
.pygments-style-bw .err { border: 1px solid #F00 } /* Error */
.pygments-style-bw .k { font-weight: bold } /* Keyword */
.pygments-style-bw .ch { font-style: italic } /* Comment.Hashbang */
.pygments-style-bw .cm { font-style: italic } /* Comment.Multiline */
.pygments-style-bw .cpf { font-style: italic } /* Comment.PreprocFile */
.pygments-style-bw .c1 { font-style: italic } /* Comment.Single */
.pygments-style-bw .cs { font-style: italic } /* Comment.Special */
.pygments-style-bw .ge { font-style: italic } /* Generic.Emph */
.pygments-style-bw .ges { font-weight: bold; 
font-style: italic } /* Generic.EmphStrong */
.pygments-style-bw .gh { font-weight: bold } /* Generic.Heading */
.pygments-style-bw .gp { font-weight: bold } /* Generic.Prompt */
.pygments-style-bw .gs { font-weight: bold } /* Generic.Strong */
.pygments-style-bw .gu { font-weight: bold } /* Generic.Subheading */
.pygments-style-bw .kc { font-weight: bold } /* Keyword.Constant */
.pygments-style-bw .kd { font-weight: bold } /* Keyword.Declaration */
.pygments-style-bw .kn { font-weight: bold } /* Keyword.Namespace */
.pygments-style-bw .kr { font-weight: bold } /* Keyword.Reserved */
.pygments-style-bw .s { font-style: italic } /* Literal.String */
.pygments-style-bw .nc { font-weight: bold } /* Name.Class */
.pygments-style-bw .ni { font-weight: bold } /* Name.Entity */
.pygments-style-bw .ne { font-weight: bold } /* Name.Exception */
.pygments-style-bw .nn { font-weight: bold } /* Name.Namespace */
.pygments-style-bw .nt { font-weight: bold } /* Name.Tag */
.pygments-style-bw .ow { font-weight: bold } /* Operator.Word */
.pygments-style-bw .sa { font-style: italic } /* Literal.String.Affix */
.pygments-style-bw .sb { font-style: italic } /* Literal.String.Backtick */
.pygments-style-bw .sc { font-style: italic } /* Literal.String.Char */
.pygments-style-bw .dl { font-style: italic } /* Literal.String.Delimiter */
.pygments-style-bw .sd { font-style: italic } /* Literal.String.Doc */
.pygments-style-bw .s2 { font-style: italic } /* Literal.String.Double */
.pygments-style-bw .se { font-weight: bold; 
font-style: italic } /* Literal.String.Escape */
.pygments-style-bw .sh { font-style: italic } /* Literal.String.Heredoc */
.pygments-style-bw .si { font-weight: bold; 
font-style: italic } /* Literal.String.Interpol */
.pygments-style-bw .sx { font-style: italic } /* Literal.String.Other */
.pygments-style-bw .sr { font-style: italic } /* Literal.String.Regex */
.pygments-style-bw .s1 { font-style: italic } /* Literal.String.Single */
.pygments-style-bw .ss { font-style: italic } /* Literal.String.Symbol */
