pre { line-height: 125%; 
}

td.linenos .normal { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

td.linenos .special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos.special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}
.pygments-style-autumn .hll { background-color: #ffc }

.pygments-style-autumn { background: #fff; 
}

.pygments-style-autumn .c { color: #aaa; 
font-style: italic } /* Comment */
.pygments-style-autumn .err { color: #F00; 
background-color: #FAA } /* Error */
.pygments-style-autumn .k { color: #00a } /* Keyword */
.pygments-style-autumn .ch { color: #aaa; 
font-style: italic } /* Comment.Hashbang */
.pygments-style-autumn .cm { color: #aaa; 
font-style: italic } /* Comment.Multiline */
.pygments-style-autumn .cp { color: #4c8317 } /* Comment.Preproc */
.pygments-style-autumn .cpf { color: #aaa; 
font-style: italic } /* Comment.PreprocFile */
.pygments-style-autumn .c1 { color: #aaa; 
font-style: italic } /* Comment.Single */
.pygments-style-autumn .cs { color: #00a; 
font-style: italic } /* Comment.Special */
.pygments-style-autumn .gd { color: #a00 } /* Generic.Deleted */
.pygments-style-autumn .ge { font-style: italic } /* Generic.Emph */
.pygments-style-autumn .ges { font-weight: bold; 
font-style: italic } /* Generic.EmphStrong */
.pygments-style-autumn .gr { color: #a00 } /* Generic.Error */
.pygments-style-autumn .gh { color: #000080; 
font-weight: bold } /* Generic.Heading */
.pygments-style-autumn .gi { color: #0a0 } /* Generic.Inserted */
.pygments-style-autumn .go { color: #888 } /* Generic.Output */
.pygments-style-autumn .gp { color: #555 } /* Generic.Prompt */
.pygments-style-autumn .gs { font-weight: bold } /* Generic.Strong */
.pygments-style-autumn .gu { color: #800080; 
font-weight: bold } /* Generic.Subheading */
.pygments-style-autumn .gt { color: #a00 } /* Generic.Traceback */
.pygments-style-autumn .kc { color: #00a } /* Keyword.Constant */
.pygments-style-autumn .kd { color: #00a } /* Keyword.Declaration */
.pygments-style-autumn .kn { color: #00a } /* Keyword.Namespace */
.pygments-style-autumn .kp { color: #00a } /* Keyword.Pseudo */
.pygments-style-autumn .kr { color: #00a } /* Keyword.Reserved */
.pygments-style-autumn .kt { color: #0aa } /* Keyword.Type */
.pygments-style-autumn .m { color: #099 } /* Literal.Number */
.pygments-style-autumn .s { color: #a50 } /* Literal.String */
.pygments-style-autumn .na { color: #1e90ff } /* Name.Attribute */
.pygments-style-autumn .nb { color: #0aa } /* Name.Builtin */
.pygments-style-autumn .nc { color: #0a0; 
text-decoration: underline } /* Name.Class */
.pygments-style-autumn .no { color: #a00 } /* Name.Constant */
.pygments-style-autumn .nd { color: #888 } /* Name.Decorator */
.pygments-style-autumn .ni { color: #800; 
font-weight: bold } /* Name.Entity */
.pygments-style-autumn .nf { color: #0a0 } /* Name.Function */
.pygments-style-autumn .nn { color: #0aa; 
text-decoration: underline } /* Name.Namespace */
.pygments-style-autumn .nt { color: #1e90ff; 
font-weight: bold } /* Name.Tag */
.pygments-style-autumn .nv { color: #a00 } /* Name.Variable */
.pygments-style-autumn .ow { color: #00a } /* Operator.Word */
.pygments-style-autumn .w { color: #bbb } /* Text.Whitespace */
.pygments-style-autumn .mb { color: #099 } /* Literal.Number.Bin */
.pygments-style-autumn .mf { color: #099 } /* Literal.Number.Float */
.pygments-style-autumn .mh { color: #099 } /* Literal.Number.Hex */
.pygments-style-autumn .mi { color: #099 } /* Literal.Number.Integer */
.pygments-style-autumn .mo { color: #099 } /* Literal.Number.Oct */
.pygments-style-autumn .sa { color: #a50 } /* Literal.String.Affix */
.pygments-style-autumn .sb { color: #a50 } /* Literal.String.Backtick */
.pygments-style-autumn .sc { color: #a50 } /* Literal.String.Char */
.pygments-style-autumn .dl { color: #a50 } /* Literal.String.Delimiter */
.pygments-style-autumn .sd { color: #a50 } /* Literal.String.Doc */
.pygments-style-autumn .s2 { color: #a50 } /* Literal.String.Double */
.pygments-style-autumn .se { color: #a50 } /* Literal.String.Escape */
.pygments-style-autumn .sh { color: #a50 } /* Literal.String.Heredoc */
.pygments-style-autumn .si { color: #a50 } /* Literal.String.Interpol */
.pygments-style-autumn .sx { color: #a50 } /* Literal.String.Other */
.pygments-style-autumn .sr { color: #099 } /* Literal.String.Regex */
.pygments-style-autumn .s1 { color: #a50 } /* Literal.String.Single */
.pygments-style-autumn .ss { color: #00a } /* Literal.String.Symbol */
.pygments-style-autumn .bp { color: #0aa } /* Name.Builtin.Pseudo */
.pygments-style-autumn .fm { color: #0a0 } /* Name.Function.Magic */
.pygments-style-autumn .vc { color: #a00 } /* Name.Variable.Class */
.pygments-style-autumn .vg { color: #a00 } /* Name.Variable.Global */
.pygments-style-autumn .vi { color: #a00 } /* Name.Variable.Instance */
.pygments-style-autumn .vm { color: #a00 } /* Name.Variable.Magic */
.pygments-style-autumn .il { color: #099 } /* Literal.Number.Integer.Long */
