.mglass {
  background-color: rgba(0, 0, 0, 0.3);
  background-image: url("/theme/img/magnifier.png");
  background-position: center;
  background-repeat: no-repeat;

  box-shadow: 0 0 10rem 0 #000 inset;
  cursor: zoom-in;
  opacity: 0;
  position: absolute;
  z-index: 10;

  &:hover {
    opacity: 1;
  }

  #content .video & {
    background-image: url("/theme/img/play-button.png");
  }
}

.mfp-with-zoom {
  .mfp-container,
  &.mfp-bg {
    backface-visibility: hidden;
    opacity: 0;
    transition: all 0.3s ease-out;
  }

  &.mfp-ready {
    .mfp-container {
      opacity: 1;
    }

    &.mfp-bg {
      opacity: 0.8;
    }
  }

  &.mfp-removing {
    .mfp-container,
    &.mfp-bg {
      opacity: 0;
    }
  }
}
