pre { line-height: 125%; 
}

td.linenos .normal { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

td.linenos .special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos.special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}
.pygments-style-manni .hll { background-color: #ffc }

.pygments-style-manni { background: #f0f3f3; 
}

.pygments-style-manni .c { color: #09F; 
font-style: italic } /* Comment */
.pygments-style-manni .err { color: #A00; 
background-color: #FAA } /* Error */
.pygments-style-manni .k { color: #069; 
font-weight: bold } /* Keyword */
.pygments-style-manni .o { color: #555 } /* Operator */
.pygments-style-manni .ch { color: #09F; 
font-style: italic } /* Comment.Hashbang */
.pygments-style-manni .cm { color: #09F; 
font-style: italic } /* Comment.Multiline */
.pygments-style-manni .cp { color: #099 } /* Comment.Preproc */
.pygments-style-manni .cpf { color: #09F; 
font-style: italic } /* Comment.PreprocFile */
.pygments-style-manni .c1 { color: #09F; 
font-style: italic } /* Comment.Single */
.pygments-style-manni .cs { color: #09F; 
font-weight: bold; 
font-style: italic } /* Comment.Special */
.pygments-style-manni .gd { background-color: #FCC; 
border: 1px solid #C00 } /* Generic.Deleted */
.pygments-style-manni .ge { font-style: italic } /* Generic.Emph */
.pygments-style-manni .ges { font-weight: bold; 
font-style: italic } /* Generic.EmphStrong */
.pygments-style-manni .gr { color: #F00 } /* Generic.Error */
.pygments-style-manni .gh { color: #030; 
font-weight: bold } /* Generic.Heading */
.pygments-style-manni .gi { background-color: #CFC; 
border: 1px solid #0C0 } /* Generic.Inserted */
.pygments-style-manni .go { color: #AAA } /* Generic.Output */
.pygments-style-manni .gp { color: #009; 
font-weight: bold } /* Generic.Prompt */
.pygments-style-manni .gs { font-weight: bold } /* Generic.Strong */
.pygments-style-manni .gu { color: #030; 
font-weight: bold } /* Generic.Subheading */
.pygments-style-manni .gt { color: #9C6 } /* Generic.Traceback */
.pygments-style-manni .kc { color: #069; 
font-weight: bold } /* Keyword.Constant */
.pygments-style-manni .kd { color: #069; 
font-weight: bold } /* Keyword.Declaration */
.pygments-style-manni .kn { color: #069; 
font-weight: bold } /* Keyword.Namespace */
.pygments-style-manni .kp { color: #069 } /* Keyword.Pseudo */
.pygments-style-manni .kr { color: #069; 
font-weight: bold } /* Keyword.Reserved */
.pygments-style-manni .kt { color: #078; 
font-weight: bold } /* Keyword.Type */
.pygments-style-manni .m { color: #F60 } /* Literal.Number */
.pygments-style-manni .s { color: #C30 } /* Literal.String */
.pygments-style-manni .na { color: #309 } /* Name.Attribute */
.pygments-style-manni .nb { color: #366 } /* Name.Builtin */
.pygments-style-manni .nc { color: #0A8; 
font-weight: bold } /* Name.Class */
.pygments-style-manni .no { color: #360 } /* Name.Constant */
.pygments-style-manni .nd { color: #99F } /* Name.Decorator */
.pygments-style-manni .ni { color: #999; 
font-weight: bold } /* Name.Entity */
.pygments-style-manni .ne { color: #C00; 
font-weight: bold } /* Name.Exception */
.pygments-style-manni .nf { color: #C0F } /* Name.Function */
.pygments-style-manni .nl { color: #99F } /* Name.Label */
.pygments-style-manni .nn { color: #0CF; 
font-weight: bold } /* Name.Namespace */
.pygments-style-manni .nt { color: #309; 
font-weight: bold } /* Name.Tag */
.pygments-style-manni .nv { color: #033 } /* Name.Variable */
.pygments-style-manni .ow { color: #000; 
font-weight: bold } /* Operator.Word */
.pygments-style-manni .w { color: #bbb } /* Text.Whitespace */
.pygments-style-manni .mb { color: #F60 } /* Literal.Number.Bin */
.pygments-style-manni .mf { color: #F60 } /* Literal.Number.Float */
.pygments-style-manni .mh { color: #F60 } /* Literal.Number.Hex */
.pygments-style-manni .mi { color: #F60 } /* Literal.Number.Integer */
.pygments-style-manni .mo { color: #F60 } /* Literal.Number.Oct */
.pygments-style-manni .sa { color: #C30 } /* Literal.String.Affix */
.pygments-style-manni .sb { color: #C30 } /* Literal.String.Backtick */
.pygments-style-manni .sc { color: #C30 } /* Literal.String.Char */
.pygments-style-manni .dl { color: #C30 } /* Literal.String.Delimiter */
.pygments-style-manni .sd { color: #C30; 
font-style: italic } /* Literal.String.Doc */
.pygments-style-manni .s2 { color: #C30 } /* Literal.String.Double */
.pygments-style-manni .se { color: #C30; 
font-weight: bold } /* Literal.String.Escape */
.pygments-style-manni .sh { color: #C30 } /* Literal.String.Heredoc */
.pygments-style-manni .si { color: #A00 } /* Literal.String.Interpol */
.pygments-style-manni .sx { color: #C30 } /* Literal.String.Other */
.pygments-style-manni .sr { color: #3AA } /* Literal.String.Regex */
.pygments-style-manni .s1 { color: #C30 } /* Literal.String.Single */
.pygments-style-manni .ss { color: #FC3 } /* Literal.String.Symbol */
.pygments-style-manni .bp { color: #366 } /* Name.Builtin.Pseudo */
.pygments-style-manni .fm { color: #C0F } /* Name.Function.Magic */
.pygments-style-manni .vc { color: #033 } /* Name.Variable.Class */
.pygments-style-manni .vg { color: #033 } /* Name.Variable.Global */
.pygments-style-manni .vi { color: #033 } /* Name.Variable.Instance */
.pygments-style-manni .vm { color: #033 } /* Name.Variable.Magic */
.pygments-style-manni .il { color: #F60 } /* Literal.Number.Integer.Long */
