pre { line-height: 125%; 
}

td.linenos .normal { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

td.linenos .special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos.special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}
.pygments-style-xcode .hll { background-color: #ffc }

.pygments-style-xcode { background: #fff; 
}
.pygments-style-xcode .c { color: #177500 } /* Comment */
.pygments-style-xcode .err { color: #000 } /* Error */
.pygments-style-xcode .k { color: #A90D91 } /* Keyword */
.pygments-style-xcode .l { color: #1C01CE } /* Literal */
.pygments-style-xcode .n { color: #000 } /* Name */
.pygments-style-xcode .o { color: #000 } /* Operator */
.pygments-style-xcode .ch { color: #177500 } /* Comment.Hashbang */
.pygments-style-xcode .cm { color: #177500 } /* Comment.Multiline */
.pygments-style-xcode .cp { color: #633820 } /* Comment.Preproc */
.pygments-style-xcode .cpf { color: #177500 } /* Comment.PreprocFile */
.pygments-style-xcode .c1 { color: #177500 } /* Comment.Single */
.pygments-style-xcode .cs { color: #177500 } /* Comment.Special */
.pygments-style-xcode .kc { color: #A90D91 } /* Keyword.Constant */
.pygments-style-xcode .kd { color: #A90D91 } /* Keyword.Declaration */
.pygments-style-xcode .kn { color: #A90D91 } /* Keyword.Namespace */
.pygments-style-xcode .kp { color: #A90D91 } /* Keyword.Pseudo */
.pygments-style-xcode .kr { color: #A90D91 } /* Keyword.Reserved */
.pygments-style-xcode .kt { color: #A90D91 } /* Keyword.Type */
.pygments-style-xcode .ld { color: #1C01CE } /* Literal.Date */
.pygments-style-xcode .m { color: #1C01CE } /* Literal.Number */
.pygments-style-xcode .s { color: #C41A16 } /* Literal.String */
.pygments-style-xcode .na { color: #836C28 } /* Name.Attribute */
.pygments-style-xcode .nb { color: #A90D91 } /* Name.Builtin */
.pygments-style-xcode .nc { color: #3F6E75 } /* Name.Class */
.pygments-style-xcode .no { color: #000 } /* Name.Constant */
.pygments-style-xcode .nd { color: #000 } /* Name.Decorator */
.pygments-style-xcode .ni { color: #000 } /* Name.Entity */
.pygments-style-xcode .ne { color: #000 } /* Name.Exception */
.pygments-style-xcode .nf { color: #000 } /* Name.Function */
.pygments-style-xcode .nl { color: #000 } /* Name.Label */
.pygments-style-xcode .nn { color: #000 } /* Name.Namespace */
.pygments-style-xcode .nx { color: #000 } /* Name.Other */
.pygments-style-xcode .py { color: #000 } /* Name.Property */
.pygments-style-xcode .nt { color: #000 } /* Name.Tag */
.pygments-style-xcode .nv { color: #000 } /* Name.Variable */
.pygments-style-xcode .ow { color: #000 } /* Operator.Word */
.pygments-style-xcode .mb { color: #1C01CE } /* Literal.Number.Bin */
.pygments-style-xcode .mf { color: #1C01CE } /* Literal.Number.Float */
.pygments-style-xcode .mh { color: #1C01CE } /* Literal.Number.Hex */
.pygments-style-xcode .mi { color: #1C01CE } /* Literal.Number.Integer */
.pygments-style-xcode .mo { color: #1C01CE } /* Literal.Number.Oct */
.pygments-style-xcode .sa { color: #C41A16 } /* Literal.String.Affix */
.pygments-style-xcode .sb { color: #C41A16 } /* Literal.String.Backtick */
.pygments-style-xcode .sc { color: #2300CE } /* Literal.String.Char */
.pygments-style-xcode .dl { color: #C41A16 } /* Literal.String.Delimiter */
.pygments-style-xcode .sd { color: #C41A16 } /* Literal.String.Doc */
.pygments-style-xcode .s2 { color: #C41A16 } /* Literal.String.Double */
.pygments-style-xcode .se { color: #C41A16 } /* Literal.String.Escape */
.pygments-style-xcode .sh { color: #C41A16 } /* Literal.String.Heredoc */
.pygments-style-xcode .si { color: #C41A16 } /* Literal.String.Interpol */
.pygments-style-xcode .sx { color: #C41A16 } /* Literal.String.Other */
.pygments-style-xcode .sr { color: #C41A16 } /* Literal.String.Regex */
.pygments-style-xcode .s1 { color: #C41A16 } /* Literal.String.Single */
.pygments-style-xcode .ss { color: #C41A16 } /* Literal.String.Symbol */
.pygments-style-xcode .bp { color: #5B269A } /* Name.Builtin.Pseudo */
.pygments-style-xcode .fm { color: #000 } /* Name.Function.Magic */
.pygments-style-xcode .vc { color: #000 } /* Name.Variable.Class */
.pygments-style-xcode .vg { color: #000 } /* Name.Variable.Global */
.pygments-style-xcode .vi { color: #000 } /* Name.Variable.Instance */
.pygments-style-xcode .vm { color: #000 } /* Name.Variable.Magic */
.pygments-style-xcode .il { color: #1C01CE } /* Literal.Number.Integer.Long */
