{% macro translations_for(article) %}
    {% if article.translations %}
        Translations:
        {% for translation in article.translations %}
            <a href="{{ SITEURL }}/{{ translation.url }}">{{ translation.lang }}</a>
        {% endfor %}
    {% endif %}
{% endmacro %}
