pre { line-height: 125%; 
}

td.linenos .normal { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

td.linenos .special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos.special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}
.pygments-style-default .hll { background-color: #ffc }

.pygments-style-default { background: #f8f8f8; 
}

.pygments-style-default .c { color: #3D7B7B; 
font-style: italic } /* Comment */
.pygments-style-default .err { border: 1px solid #F00 } /* Error */
.pygments-style-default .k { color: #008000; 
font-weight: bold } /* Keyword */
.pygments-style-default .o { color: #666 } /* Operator */
.pygments-style-default .ch { color: #3D7B7B; 
font-style: italic } /* Comment.Hashbang */
.pygments-style-default .cm { color: #3D7B7B; 
font-style: italic } /* Comment.Multiline */
.pygments-style-default .cp { color: #9C6500 } /* Comment.Preproc */
.pygments-style-default .cpf { color: #3D7B7B; 
font-style: italic } /* Comment.PreprocFile */
.pygments-style-default .c1 { color: #3D7B7B; 
font-style: italic } /* Comment.Single */
.pygments-style-default .cs { color: #3D7B7B; 
font-style: italic } /* Comment.Special */
.pygments-style-default .gd { color: #A00000 } /* Generic.Deleted */
.pygments-style-default .ge { font-style: italic } /* Generic.Emph */
.pygments-style-default .ges { font-weight: bold; 
font-style: italic } /* Generic.EmphStrong */
.pygments-style-default .gr { color: #E40000 } /* Generic.Error */
.pygments-style-default .gh { color: #000080; 
font-weight: bold } /* Generic.Heading */
.pygments-style-default .gi { color: #008400 } /* Generic.Inserted */
.pygments-style-default .go { color: #717171 } /* Generic.Output */
.pygments-style-default .gp { color: #000080; 
font-weight: bold } /* Generic.Prompt */
.pygments-style-default .gs { font-weight: bold } /* Generic.Strong */
.pygments-style-default .gu { color: #800080; 
font-weight: bold } /* Generic.Subheading */
.pygments-style-default .gt { color: #04D } /* Generic.Traceback */
.pygments-style-default .kc { color: #008000; 
font-weight: bold } /* Keyword.Constant */
.pygments-style-default .kd { color: #008000; 
font-weight: bold } /* Keyword.Declaration */
.pygments-style-default .kn { color: #008000; 
font-weight: bold } /* Keyword.Namespace */
.pygments-style-default .kp { color: #008000 } /* Keyword.Pseudo */
.pygments-style-default .kr { color: #008000; 
font-weight: bold } /* Keyword.Reserved */
.pygments-style-default .kt { color: #B00040 } /* Keyword.Type */
.pygments-style-default .m { color: #666 } /* Literal.Number */
.pygments-style-default .s { color: #BA2121 } /* Literal.String */
.pygments-style-default .na { color: #687822 } /* Name.Attribute */
.pygments-style-default .nb { color: #008000 } /* Name.Builtin */
.pygments-style-default .nc { color: #00F; 
font-weight: bold } /* Name.Class */
.pygments-style-default .no { color: #800 } /* Name.Constant */
.pygments-style-default .nd { color: #A2F } /* Name.Decorator */
.pygments-style-default .ni { color: #717171; 
font-weight: bold } /* Name.Entity */
.pygments-style-default .ne { color: #CB3F38; 
font-weight: bold } /* Name.Exception */
.pygments-style-default .nf { color: #00F } /* Name.Function */
.pygments-style-default .nl { color: #767600 } /* Name.Label */
.pygments-style-default .nn { color: #00F; 
font-weight: bold } /* Name.Namespace */
.pygments-style-default .nt { color: #008000; 
font-weight: bold } /* Name.Tag */
.pygments-style-default .nv { color: #19177C } /* Name.Variable */
.pygments-style-default .ow { color: #A2F; 
font-weight: bold } /* Operator.Word */
.pygments-style-default .w { color: #bbb } /* Text.Whitespace */
.pygments-style-default .mb { color: #666 } /* Literal.Number.Bin */
.pygments-style-default .mf { color: #666 } /* Literal.Number.Float */
.pygments-style-default .mh { color: #666 } /* Literal.Number.Hex */
.pygments-style-default .mi { color: #666 } /* Literal.Number.Integer */
.pygments-style-default .mo { color: #666 } /* Literal.Number.Oct */
.pygments-style-default .sa { color: #BA2121 } /* Literal.String.Affix */
.pygments-style-default .sb { color: #BA2121 } /* Literal.String.Backtick */
.pygments-style-default .sc { color: #BA2121 } /* Literal.String.Char */
.pygments-style-default .dl { color: #BA2121 } /* Literal.String.Delimiter */
.pygments-style-default .sd { color: #BA2121; 
font-style: italic } /* Literal.String.Doc */
.pygments-style-default .s2 { color: #BA2121 } /* Literal.String.Double */
.pygments-style-default .se { color: #AA5D1F; 
font-weight: bold } /* Literal.String.Escape */
.pygments-style-default .sh { color: #BA2121 } /* Literal.String.Heredoc */
.pygments-style-default .si { color: #A45A77; 
font-weight: bold } /* Literal.String.Interpol */
.pygments-style-default .sx { color: #008000 } /* Literal.String.Other */
.pygments-style-default .sr { color: #A45A77 } /* Literal.String.Regex */
.pygments-style-default .s1 { color: #BA2121 } /* Literal.String.Single */
.pygments-style-default .ss { color: #19177C } /* Literal.String.Symbol */
.pygments-style-default .bp { color: #008000 } /* Name.Builtin.Pseudo */
.pygments-style-default .fm { color: #00F } /* Name.Function.Magic */
.pygments-style-default .vc { color: #19177C } /* Name.Variable.Class */
.pygments-style-default .vg { color: #19177C } /* Name.Variable.Global */
.pygments-style-default .vi { color: #19177C } /* Name.Variable.Instance */
.pygments-style-default .vm { color: #19177C } /* Name.Variable.Magic */
.pygments-style-default .il { color: #666 } /* Literal.Number.Integer.Long */
