{% extends "base.html" %}
{% block title %}{{ tag }}{% endblock title %}
{% block top_center %}
    <h1>
        <a href="{{ SITEURL }}/{{ tag.url }}"
           rel="bookmark"
           title="Permalink to {{ tag|e }} articles">{{ tag }} articles</a>
    </h1>
{% endblock top_center %}
{% block content %}
    <dl class="row">
        {% for article in articles %}
            <dt class="col-sm-3">
                <abbr class="published" title="{{ article.date.isoformat() }}">{{ article.locale_date }}</abbr>
            </dt>
            <dd class="col-sm-9">
                <a href="{{ SITEURL }}/{{ article.url }}">{{ article.title }}</a>
            </dd>
        {% endfor %}
    </dl>
{% endblock content %}
