pre { line-height: 125%; 
}

td.linenos .normal { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

td.linenos .special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos.special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}
.pygments-style-trac .hll { background-color: #ffc }

.pygments-style-trac { background: #fff; 
}

.pygments-style-trac .c { color: #998; 
font-style: italic } /* Comment */
.pygments-style-trac .err { color: #a61717; 
background-color: #e3d2d2 } /* Error */
.pygments-style-trac .k { font-weight: bold } /* Keyword */
.pygments-style-trac .o { font-weight: bold } /* Operator */
.pygments-style-trac .ch { color: #998; 
font-style: italic } /* Comment.Hashbang */
.pygments-style-trac .cm { color: #998; 
font-style: italic } /* Comment.Multiline */
.pygments-style-trac .cp { color: #999; 
font-weight: bold } /* Comment.Preproc */
.pygments-style-trac .cpf { color: #998; 
font-style: italic } /* Comment.PreprocFile */
.pygments-style-trac .c1 { color: #998; 
font-style: italic } /* Comment.Single */
.pygments-style-trac .cs { color: #999; 
font-weight: bold; 
font-style: italic } /* Comment.Special */
.pygments-style-trac .gd { color: #000; 
background-color: #fdd } /* Generic.Deleted */
.pygments-style-trac .ge { font-style: italic } /* Generic.Emph */
.pygments-style-trac .ges { font-weight: bold; 
font-style: italic } /* Generic.EmphStrong */
.pygments-style-trac .gr { color: #a00 } /* Generic.Error */
.pygments-style-trac .gh { color: #999 } /* Generic.Heading */
.pygments-style-trac .gi { color: #000; 
background-color: #dfd } /* Generic.Inserted */
.pygments-style-trac .go { color: #888 } /* Generic.Output */
.pygments-style-trac .gp { color: #555 } /* Generic.Prompt */
.pygments-style-trac .gs { font-weight: bold } /* Generic.Strong */
.pygments-style-trac .gu { color: #aaa } /* Generic.Subheading */
.pygments-style-trac .gt { color: #a00 } /* Generic.Traceback */
.pygments-style-trac .kc { font-weight: bold } /* Keyword.Constant */
.pygments-style-trac .kd { font-weight: bold } /* Keyword.Declaration */
.pygments-style-trac .kn { font-weight: bold } /* Keyword.Namespace */
.pygments-style-trac .kp { font-weight: bold } /* Keyword.Pseudo */
.pygments-style-trac .kr { font-weight: bold } /* Keyword.Reserved */
.pygments-style-trac .kt { color: #458; 
font-weight: bold } /* Keyword.Type */
.pygments-style-trac .m { color: #099 } /* Literal.Number */
.pygments-style-trac .s { color: #b84 } /* Literal.String */
.pygments-style-trac .na { color: #008080 } /* Name.Attribute */
.pygments-style-trac .nb { color: #999 } /* Name.Builtin */
.pygments-style-trac .nc { color: #458; 
font-weight: bold } /* Name.Class */
.pygments-style-trac .no { color: #008080 } /* Name.Constant */
.pygments-style-trac .ni { color: #800080 } /* Name.Entity */
.pygments-style-trac .ne { color: #900; 
font-weight: bold } /* Name.Exception */
.pygments-style-trac .nf { color: #900; 
font-weight: bold } /* Name.Function */
.pygments-style-trac .nn { color: #555 } /* Name.Namespace */
.pygments-style-trac .nt { color: #000080 } /* Name.Tag */
.pygments-style-trac .nv { color: #008080 } /* Name.Variable */
.pygments-style-trac .ow { font-weight: bold } /* Operator.Word */
.pygments-style-trac .w { color: #bbb } /* Text.Whitespace */
.pygments-style-trac .mb { color: #099 } /* Literal.Number.Bin */
.pygments-style-trac .mf { color: #099 } /* Literal.Number.Float */
.pygments-style-trac .mh { color: #099 } /* Literal.Number.Hex */
.pygments-style-trac .mi { color: #099 } /* Literal.Number.Integer */
.pygments-style-trac .mo { color: #099 } /* Literal.Number.Oct */
.pygments-style-trac .sa { color: #b84 } /* Literal.String.Affix */
.pygments-style-trac .sb { color: #b84 } /* Literal.String.Backtick */
.pygments-style-trac .sc { color: #b84 } /* Literal.String.Char */
.pygments-style-trac .dl { color: #b84 } /* Literal.String.Delimiter */
.pygments-style-trac .sd { color: #b84 } /* Literal.String.Doc */
.pygments-style-trac .s2 { color: #b84 } /* Literal.String.Double */
.pygments-style-trac .se { color: #b84 } /* Literal.String.Escape */
.pygments-style-trac .sh { color: #b84 } /* Literal.String.Heredoc */
.pygments-style-trac .si { color: #b84 } /* Literal.String.Interpol */
.pygments-style-trac .sx { color: #b84 } /* Literal.String.Other */
.pygments-style-trac .sr { color: #808000 } /* Literal.String.Regex */
.pygments-style-trac .s1 { color: #b84 } /* Literal.String.Single */
.pygments-style-trac .ss { color: #b84 } /* Literal.String.Symbol */
.pygments-style-trac .bp { color: #999 } /* Name.Builtin.Pseudo */
.pygments-style-trac .fm { color: #900; 
font-weight: bold } /* Name.Function.Magic */
.pygments-style-trac .vc { color: #008080 } /* Name.Variable.Class */
.pygments-style-trac .vg { color: #008080 } /* Name.Variable.Global */
.pygments-style-trac .vi { color: #008080 } /* Name.Variable.Instance */
.pygments-style-trac .vm { color: #008080 } /* Name.Variable.Magic */
.pygments-style-trac .il { color: #099 } /* Literal.Number.Integer.Long */
