pre { line-height: 125%; 
}

td.linenos .normal { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

td.linenos .special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos.special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}
.pygments-style-lovelace .hll { background-color: #ffc }

.pygments-style-lovelace { background: #fff; 
}

.pygments-style-lovelace .c { color: #888; 
font-style: italic } /* Comment */
.pygments-style-lovelace .err { background-color: #a848a8 } /* Error */
.pygments-style-lovelace .k { color: #2838b0 } /* Keyword */
.pygments-style-lovelace .o { color: #666 } /* Operator */
.pygments-style-lovelace .p { color: #888 } /* Punctuation */
.pygments-style-lovelace .ch { color: #287088; 
font-style: italic } /* Comment.Hashbang */
.pygments-style-lovelace .cm { color: #888; 
font-style: italic } /* Comment.Multiline */
.pygments-style-lovelace .cp { color: #289870 } /* Comment.Preproc */
.pygments-style-lovelace .cpf { color: #888; 
font-style: italic } /* Comment.PreprocFile */
.pygments-style-lovelace .c1 { color: #888; 
font-style: italic } /* Comment.Single */
.pygments-style-lovelace .cs { color: #888; 
font-style: italic } /* Comment.Special */
.pygments-style-lovelace .gd { color: #c02828 } /* Generic.Deleted */
.pygments-style-lovelace .ge { font-style: italic } /* Generic.Emph */
.pygments-style-lovelace .ges { font-weight: bold; 
font-style: italic } /* Generic.EmphStrong */
.pygments-style-lovelace .gr { color: #c02828 } /* Generic.Error */
.pygments-style-lovelace .gh { color: #666 } /* Generic.Heading */
.pygments-style-lovelace .gi { color: #388038 } /* Generic.Inserted */
.pygments-style-lovelace .go { color: #666 } /* Generic.Output */
.pygments-style-lovelace .gp { color: #444 } /* Generic.Prompt */
.pygments-style-lovelace .gs { font-weight: bold } /* Generic.Strong */
.pygments-style-lovelace .gu { color: #444 } /* Generic.Subheading */
.pygments-style-lovelace .gt { color: #2838b0 } /* Generic.Traceback */
.pygments-style-lovelace .kc { color: #444; 
font-style: italic } /* Keyword.Constant */
.pygments-style-lovelace .kd { color: #2838b0; 
font-style: italic } /* Keyword.Declaration */
.pygments-style-lovelace .kn { color: #2838b0 } /* Keyword.Namespace */
.pygments-style-lovelace .kp { color: #2838b0 } /* Keyword.Pseudo */
.pygments-style-lovelace .kr { color: #2838b0 } /* Keyword.Reserved */
.pygments-style-lovelace .kt { color: #2838b0; 
font-style: italic } /* Keyword.Type */
.pygments-style-lovelace .m { color: #444 } /* Literal.Number */
.pygments-style-lovelace .s { color: #b83838 } /* Literal.String */
.pygments-style-lovelace .na { color: #388038 } /* Name.Attribute */
.pygments-style-lovelace .nb { color: #388038 } /* Name.Builtin */
.pygments-style-lovelace .nc { color: #287088 } /* Name.Class */
.pygments-style-lovelace .no { color: #b85820 } /* Name.Constant */
.pygments-style-lovelace .nd { color: #287088 } /* Name.Decorator */
.pygments-style-lovelace .ni { color: #709030 } /* Name.Entity */
.pygments-style-lovelace .ne { color: #908828 } /* Name.Exception */
.pygments-style-lovelace .nf { color: #785840 } /* Name.Function */
.pygments-style-lovelace .nl { color: #289870 } /* Name.Label */
.pygments-style-lovelace .nn { color: #289870 } /* Name.Namespace */
.pygments-style-lovelace .nt { color: #2838b0 } /* Name.Tag */
.pygments-style-lovelace .nv { color: #b04040 } /* Name.Variable */
.pygments-style-lovelace .ow { color: #a848a8 } /* Operator.Word */
.pygments-style-lovelace .pm { color: #888 } /* Punctuation.Marker */
.pygments-style-lovelace .w { color: #a89028 } /* Text.Whitespace */
.pygments-style-lovelace .mb { color: #444 } /* Literal.Number.Bin */
.pygments-style-lovelace .mf { color: #444 } /* Literal.Number.Float */
.pygments-style-lovelace .mh { color: #444 } /* Literal.Number.Hex */
.pygments-style-lovelace .mi { color: #444 } /* Literal.Number.Integer */
.pygments-style-lovelace .mo { color: #444 } /* Literal.Number.Oct */
.pygments-style-lovelace .sa { color: #444 } /* Literal.String.Affix */
.pygments-style-lovelace .sb { color: #b83838 } /* Literal.String.Backtick */
.pygments-style-lovelace .sc { color: #a848a8 } /* Literal.String.Char */
.pygments-style-lovelace .dl { color: #b85820 } /* Literal.String.Delimiter */
.pygments-style-lovelace .sd { color: #b85820; 
font-style: italic } /* Literal.String.Doc */
.pygments-style-lovelace .s2 { color: #b83838 } /* Literal.String.Double */
.pygments-style-lovelace .se { color: #709030 } /* Literal.String.Escape */
.pygments-style-lovelace .sh { color: #b83838 } /* Literal.String.Heredoc */
.pygments-style-lovelace .si { color: #b83838; 
text-decoration: underline } /* Literal.String.Interpol */
.pygments-style-lovelace .sx { color: #a848a8 } /* Literal.String.Other */
.pygments-style-lovelace .sr { color: #a848a8 } /* Literal.String.Regex */
.pygments-style-lovelace .s1 { color: #b83838 } /* Literal.String.Single */
.pygments-style-lovelace .ss { color: #b83838 } /* Literal.String.Symbol */
.pygments-style-lovelace .bp { color: #388038; 
font-style: italic } /* Name.Builtin.Pseudo */
.pygments-style-lovelace .fm { color: #b85820 } /* Name.Function.Magic */
.pygments-style-lovelace .vc { color: #b04040 } /* Name.Variable.Class */
.pygments-style-lovelace .vg { color: #908828 } /* Name.Variable.Global */
.pygments-style-lovelace .vi { color: #b04040 } /* Name.Variable.Instance */
.pygments-style-lovelace .vm { color: #b85820 } /* Name.Variable.Magic */
.pygments-style-lovelace .il { color: #444 } /* Literal.Number.Integer.Long */
