pre { line-height: 125%; 
}

td.linenos .normal { color: #93a1a1; 
background-color: #eee8d5; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos { color: #93a1a1; 
background-color: #eee8d5; 
padding-left: 5px; 
padding-right: 5px; 
}

td.linenos .special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos.special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}
.pygments-style-solarized-light .hll { background-color: #eee8d5 }

.pygments-style-solarized-light { background: #fdf6e3; 
color: #657b83 }

.pygments-style-solarized-light .c { color: #93a1a1; 
font-style: italic } /* Comment */
.pygments-style-solarized-light .err { color: #657b83; 
background-color: #dc322f } /* Error */
.pygments-style-solarized-light .esc { color: #657b83 } /* Escape */
.pygments-style-solarized-light .g { color: #657b83 } /* Generic */
.pygments-style-solarized-light .k { color: #859900 } /* Keyword */
.pygments-style-solarized-light .l { color: #657b83 } /* Literal */
.pygments-style-solarized-light .n { color: #657b83 } /* Name */
.pygments-style-solarized-light .o { color: #93a1a1 } /* Operator */
.pygments-style-solarized-light .x { color: #657b83 } /* Other */
.pygments-style-solarized-light .p { color: #657b83 } /* Punctuation */
.pygments-style-solarized-light .ch { color: #93a1a1; 
font-style: italic } /* Comment.Hashbang */
.pygments-style-solarized-light .cm { color: #93a1a1; 
font-style: italic } /* Comment.Multiline */
.pygments-style-solarized-light .cp { color: #d33682 } /* Comment.Preproc */
.pygments-style-solarized-light .cpf { color: #93a1a1 } /* Comment.PreprocFile */
.pygments-style-solarized-light .c1 { color: #93a1a1; 
font-style: italic } /* Comment.Single */
.pygments-style-solarized-light .cs { color: #93a1a1; 
font-style: italic } /* Comment.Special */
.pygments-style-solarized-light .gd { color: #dc322f } /* Generic.Deleted */
.pygments-style-solarized-light .ge { color: #657b83; 
font-style: italic } /* Generic.Emph */
.pygments-style-solarized-light .ges { color: #657b83; 
font-weight: bold; 
font-style: italic } /* Generic.EmphStrong */
.pygments-style-solarized-light .gr { color: #dc322f } /* Generic.Error */
.pygments-style-solarized-light .gh { color: #657b83; 
font-weight: bold } /* Generic.Heading */
.pygments-style-solarized-light .gi { color: #859900 } /* Generic.Inserted */
.pygments-style-solarized-light .go { color: #657b83 } /* Generic.Output */
.pygments-style-solarized-light .gp { color: #268bd2; 
font-weight: bold } /* Generic.Prompt */
.pygments-style-solarized-light .gs { color: #657b83; 
font-weight: bold } /* Generic.Strong */
.pygments-style-solarized-light .gu { color: #657b83; 
text-decoration: underline } /* Generic.Subheading */
.pygments-style-solarized-light .gt { color: #268bd2 } /* Generic.Traceback */
.pygments-style-solarized-light .kc { color: #2aa198 } /* Keyword.Constant */
.pygments-style-solarized-light .kd { color: #2aa198 } /* Keyword.Declaration */
.pygments-style-solarized-light .kn { color: #cb4b16 } /* Keyword.Namespace */
.pygments-style-solarized-light .kp { color: #859900 } /* Keyword.Pseudo */
.pygments-style-solarized-light .kr { color: #859900 } /* Keyword.Reserved */
.pygments-style-solarized-light .kt { color: #b58900 } /* Keyword.Type */
.pygments-style-solarized-light .ld { color: #657b83 } /* Literal.Date */
.pygments-style-solarized-light .m { color: #2aa198 } /* Literal.Number */
.pygments-style-solarized-light .s { color: #2aa198 } /* Literal.String */
.pygments-style-solarized-light .na { color: #657b83 } /* Name.Attribute */
.pygments-style-solarized-light .nb { color: #268bd2 } /* Name.Builtin */
.pygments-style-solarized-light .nc { color: #268bd2 } /* Name.Class */
.pygments-style-solarized-light .no { color: #268bd2 } /* Name.Constant */
.pygments-style-solarized-light .nd { color: #268bd2 } /* Name.Decorator */
.pygments-style-solarized-light .ni { color: #268bd2 } /* Name.Entity */
.pygments-style-solarized-light .ne { color: #268bd2 } /* Name.Exception */
.pygments-style-solarized-light .nf { color: #268bd2 } /* Name.Function */
.pygments-style-solarized-light .nl { color: #268bd2 } /* Name.Label */
.pygments-style-solarized-light .nn { color: #268bd2 } /* Name.Namespace */
.pygments-style-solarized-light .nx { color: #657b83 } /* Name.Other */
.pygments-style-solarized-light .py { color: #657b83 } /* Name.Property */
.pygments-style-solarized-light .nt { color: #268bd2 } /* Name.Tag */
.pygments-style-solarized-light .nv { color: #268bd2 } /* Name.Variable */
.pygments-style-solarized-light .ow { color: #859900 } /* Operator.Word */
.pygments-style-solarized-light .pm { color: #657b83 } /* Punctuation.Marker */
.pygments-style-solarized-light .w { color: #657b83 } /* Text.Whitespace */
.pygments-style-solarized-light .mb { color: #2aa198 } /* Literal.Number.Bin */
.pygments-style-solarized-light .mf { color: #2aa198 } /* Literal.Number.Float */
.pygments-style-solarized-light .mh { color: #2aa198 } /* Literal.Number.Hex */
.pygments-style-solarized-light .mi { color: #2aa198 } /* Literal.Number.Integer */
.pygments-style-solarized-light .mo { color: #2aa198 } /* Literal.Number.Oct */
.pygments-style-solarized-light .sa { color: #2aa198 } /* Literal.String.Affix */
.pygments-style-solarized-light .sb { color: #2aa198 } /* Literal.String.Backtick */
.pygments-style-solarized-light .sc { color: #2aa198 } /* Literal.String.Char */
.pygments-style-solarized-light .dl { color: #2aa198 } /* Literal.String.Delimiter */
.pygments-style-solarized-light .sd { color: #93a1a1 } /* Literal.String.Doc */
.pygments-style-solarized-light .s2 { color: #2aa198 } /* Literal.String.Double */
.pygments-style-solarized-light .se { color: #2aa198 } /* Literal.String.Escape */
.pygments-style-solarized-light .sh { color: #2aa198 } /* Literal.String.Heredoc */
.pygments-style-solarized-light .si { color: #2aa198 } /* Literal.String.Interpol */
.pygments-style-solarized-light .sx { color: #2aa198 } /* Literal.String.Other */
.pygments-style-solarized-light .sr { color: #cb4b16 } /* Literal.String.Regex */
.pygments-style-solarized-light .s1 { color: #2aa198 } /* Literal.String.Single */
.pygments-style-solarized-light .ss { color: #2aa198 } /* Literal.String.Symbol */
.pygments-style-solarized-light .bp { color: #268bd2 } /* Name.Builtin.Pseudo */
.pygments-style-solarized-light .fm { color: #268bd2 } /* Name.Function.Magic */
.pygments-style-solarized-light .vc { color: #268bd2 } /* Name.Variable.Class */
.pygments-style-solarized-light .vg { color: #268bd2 } /* Name.Variable.Global */
.pygments-style-solarized-light .vi { color: #268bd2 } /* Name.Variable.Instance */
.pygments-style-solarized-light .vm { color: #268bd2 } /* Name.Variable.Magic */
.pygments-style-solarized-light .il { color: #2aa198 } /* Literal.Number.Integer.Long */
