pre { line-height: 125%; 
}

td.linenos .normal { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

td.linenos .special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos.special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}
.pygments-style-emacs .hll { background-color: #ffc }

.pygments-style-emacs { background: #f8f8f8; 
}

.pygments-style-emacs .c { color: #080; 
font-style: italic } /* Comment */
.pygments-style-emacs .err { border: 1px solid #F00 } /* Error */
.pygments-style-emacs .k { color: #A2F; 
font-weight: bold } /* Keyword */
.pygments-style-emacs .o { color: #666 } /* Operator */
.pygments-style-emacs .ch { color: #080; 
font-style: italic } /* Comment.Hashbang */
.pygments-style-emacs .cm { color: #080; 
font-style: italic } /* Comment.Multiline */
.pygments-style-emacs .cp { color: #080 } /* Comment.Preproc */
.pygments-style-emacs .cpf { color: #080; 
font-style: italic } /* Comment.PreprocFile */
.pygments-style-emacs .c1 { color: #080; 
font-style: italic } /* Comment.Single */
.pygments-style-emacs .cs { color: #080; 
font-weight: bold } /* Comment.Special */
.pygments-style-emacs .gd { color: #A00000 } /* Generic.Deleted */
.pygments-style-emacs .ge { font-style: italic } /* Generic.Emph */
.pygments-style-emacs .ges { font-weight: bold; 
font-style: italic } /* Generic.EmphStrong */
.pygments-style-emacs .gr { color: #F00 } /* Generic.Error */
.pygments-style-emacs .gh { color: #000080; 
font-weight: bold } /* Generic.Heading */
.pygments-style-emacs .gi { color: #00A000 } /* Generic.Inserted */
.pygments-style-emacs .go { color: #888 } /* Generic.Output */
.pygments-style-emacs .gp { color: #000080; 
font-weight: bold } /* Generic.Prompt */
.pygments-style-emacs .gs { font-weight: bold } /* Generic.Strong */
.pygments-style-emacs .gu { color: #800080; 
font-weight: bold } /* Generic.Subheading */
.pygments-style-emacs .gt { color: #04D } /* Generic.Traceback */
.pygments-style-emacs .kc { color: #A2F; 
font-weight: bold } /* Keyword.Constant */
.pygments-style-emacs .kd { color: #A2F; 
font-weight: bold } /* Keyword.Declaration */
.pygments-style-emacs .kn { color: #A2F; 
font-weight: bold } /* Keyword.Namespace */
.pygments-style-emacs .kp { color: #A2F } /* Keyword.Pseudo */
.pygments-style-emacs .kr { color: #A2F; 
font-weight: bold } /* Keyword.Reserved */
.pygments-style-emacs .kt { color: #0B0; 
font-weight: bold } /* Keyword.Type */
.pygments-style-emacs .m { color: #666 } /* Literal.Number */
.pygments-style-emacs .s { color: #B44 } /* Literal.String */
.pygments-style-emacs .na { color: #B44 } /* Name.Attribute */
.pygments-style-emacs .nb { color: #A2F } /* Name.Builtin */
.pygments-style-emacs .nc { color: #00F } /* Name.Class */
.pygments-style-emacs .no { color: #800 } /* Name.Constant */
.pygments-style-emacs .nd { color: #A2F } /* Name.Decorator */
.pygments-style-emacs .ni { color: #999; 
font-weight: bold } /* Name.Entity */
.pygments-style-emacs .ne { color: #D2413A; 
font-weight: bold } /* Name.Exception */
.pygments-style-emacs .nf { color: #00A000 } /* Name.Function */
.pygments-style-emacs .nl { color: #A0A000 } /* Name.Label */
.pygments-style-emacs .nn { color: #00F; 
font-weight: bold } /* Name.Namespace */
.pygments-style-emacs .nt { color: #008000; 
font-weight: bold } /* Name.Tag */
.pygments-style-emacs .nv { color: #B8860B } /* Name.Variable */
.pygments-style-emacs .ow { color: #A2F; 
font-weight: bold } /* Operator.Word */
.pygments-style-emacs .w { color: #bbb } /* Text.Whitespace */
.pygments-style-emacs .mb { color: #666 } /* Literal.Number.Bin */
.pygments-style-emacs .mf { color: #666 } /* Literal.Number.Float */
.pygments-style-emacs .mh { color: #666 } /* Literal.Number.Hex */
.pygments-style-emacs .mi { color: #666 } /* Literal.Number.Integer */
.pygments-style-emacs .mo { color: #666 } /* Literal.Number.Oct */
.pygments-style-emacs .sa { color: #B44 } /* Literal.String.Affix */
.pygments-style-emacs .sb { color: #B44 } /* Literal.String.Backtick */
.pygments-style-emacs .sc { color: #B44 } /* Literal.String.Char */
.pygments-style-emacs .dl { color: #B44 } /* Literal.String.Delimiter */
.pygments-style-emacs .sd { color: #B44; 
font-style: italic } /* Literal.String.Doc */
.pygments-style-emacs .s2 { color: #B44 } /* Literal.String.Double */
.pygments-style-emacs .se { color: #B62; 
font-weight: bold } /* Literal.String.Escape */
.pygments-style-emacs .sh { color: #B44 } /* Literal.String.Heredoc */
.pygments-style-emacs .si { color: #B68; 
font-weight: bold } /* Literal.String.Interpol */
.pygments-style-emacs .sx { color: #008000 } /* Literal.String.Other */
.pygments-style-emacs .sr { color: #B68 } /* Literal.String.Regex */
.pygments-style-emacs .s1 { color: #B44 } /* Literal.String.Single */
.pygments-style-emacs .ss { color: #B8860B } /* Literal.String.Symbol */
.pygments-style-emacs .bp { color: #A2F } /* Name.Builtin.Pseudo */
.pygments-style-emacs .fm { color: #00A000 } /* Name.Function.Magic */
.pygments-style-emacs .vc { color: #B8860B } /* Name.Variable.Class */
.pygments-style-emacs .vg { color: #B8860B } /* Name.Variable.Global */
.pygments-style-emacs .vi { color: #B8860B } /* Name.Variable.Instance */
.pygments-style-emacs .vm { color: #B8860B } /* Name.Variable.Magic */
.pygments-style-emacs .il { color: #666 } /* Literal.Number.Integer.Long */
