pre { line-height: 125%; 
}

td.linenos .normal { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos { color: inherit; 
background-color: transparent; 
padding-left: 5px; 
padding-right: 5px; 
}

td.linenos .special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}

span.linenos.special { color: #000; 
background-color: #ffffc0; 
padding-left: 5px; 
padding-right: 5px; 
}
.pygments-style-igor .hll { background-color: #ffc }

.pygments-style-igor { background: #fff; 
}

.pygments-style-igor .c { color: #F00; 
font-style: italic } /* Comment */
.pygments-style-igor .k { color: #00F } /* Keyword */
.pygments-style-igor .ch { color: #F00; 
font-style: italic } /* Comment.Hashbang */
.pygments-style-igor .cm { color: #F00; 
font-style: italic } /* Comment.Multiline */
.pygments-style-igor .cp { color: #F00; 
font-style: italic } /* Comment.Preproc */
.pygments-style-igor .cpf { color: #F00; 
font-style: italic } /* Comment.PreprocFile */
.pygments-style-igor .c1 { color: #F00; 
font-style: italic } /* Comment.Single */
.pygments-style-igor .cs { color: #F00; 
font-style: italic } /* Comment.Special */
.pygments-style-igor .kc { color: #00F } /* Keyword.Constant */
.pygments-style-igor .kd { color: #00F } /* Keyword.Declaration */
.pygments-style-igor .kn { color: #00F } /* Keyword.Namespace */
.pygments-style-igor .kp { color: #00F } /* Keyword.Pseudo */
.pygments-style-igor .kr { color: #00F } /* Keyword.Reserved */
.pygments-style-igor .kt { color: #00F } /* Keyword.Type */
.pygments-style-igor .s { color: #009C00 } /* Literal.String */
.pygments-style-igor .nc { color: #007575 } /* Name.Class */
.pygments-style-igor .nd { color: #CC00A3 } /* Name.Decorator */
.pygments-style-igor .nf { color: #C34E00 } /* Name.Function */
.pygments-style-igor .sa { color: #009C00 } /* Literal.String.Affix */
.pygments-style-igor .sb { color: #009C00 } /* Literal.String.Backtick */
.pygments-style-igor .sc { color: #009C00 } /* Literal.String.Char */
.pygments-style-igor .dl { color: #009C00 } /* Literal.String.Delimiter */
.pygments-style-igor .sd { color: #009C00 } /* Literal.String.Doc */
.pygments-style-igor .s2 { color: #009C00 } /* Literal.String.Double */
.pygments-style-igor .se { color: #009C00 } /* Literal.String.Escape */
.pygments-style-igor .sh { color: #009C00 } /* Literal.String.Heredoc */
.pygments-style-igor .si { color: #009C00 } /* Literal.String.Interpol */
.pygments-style-igor .sx { color: #009C00 } /* Literal.String.Other */
.pygments-style-igor .sr { color: #009C00 } /* Literal.String.Regex */
.pygments-style-igor .s1 { color: #009C00 } /* Literal.String.Single */
.pygments-style-igor .ss { color: #009C00 } /* Literal.String.Symbol */
.pygments-style-igor .fm { color: #C34E00 } /* Name.Function.Magic */
